==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/components/camel-freemarker/src/test/java/org/apache/camel/component/freemarker/FreemarkerValuesInPropertiesTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.freemarker;

import org.apache.camel.EndpointInject;
import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.junit4.CamelTestSupport;
import org.junit.Test;

public class FreemarkerValuesInPropertiesTest extends CamelTestSupport {
    
    @EndpointInject(uri = "mock:result")
    private MockEndpoint mock;

    @Test
    public void testVelocityLetter() throws Exception {
        mock.expectedBodiesReceived("Dear Christian. You ordered item 7.");

        template.send("direct:a", new Processor() {
            @Override
            public void process(Exchange exchange) throws Exception {
                exchange.getIn().setHeader(FreemarkerConstants.FREEMARKER_TEMPLATE, "Dear ${exchange.properties.name}. You ordered item ${exchange.properties.item}.");
                exchange.setProperty("name", "Christian");
                exchange.setProperty("item", "7");
            }
        });

        mock.assertIsSatisfied();
    }

    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            public void configure() throws Exception {
                FreemarkerComponent fc = context.getComponent("freemarker", FreemarkerComponent.class);
                fc.setAllowTemplateFromHeader(true);
                fc.setAllowContextMapAll(true);

                from("direct:a")
                    .to("freemarker:dummy")
                    .to("mock:result");
            }
        };
    }
}

==> apache-camel-3.3.0-src.zip: apache-camel-3.3.0/components/camel-freemarker/src/test/java/org/apache/camel/component/freemarker/FreemarkerValuesInPropertiesTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.freemarker;

import org.apache.camel.EndpointInject;
import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.junit4.CamelTestSupport;
import org.junit.Test;

public class FreemarkerValuesInPropertiesTest extends CamelTestSupport {
    
    @EndpointInject("mock:result")
    private MockEndpoint mock;

    @Test
    public void testVelocityLetter() throws Exception {
        mock.expectedBodiesReceived("Dear Christian. You ordered item 7.");

        template.send("direct:a", new Processor() {
            @Override
            public void process(Exchange exchange) throws Exception {
                exchange.getIn().setHeader(FreemarkerConstants.FREEMARKER_TEMPLATE, "Dear ${exchange.properties.name}. You ordered item ${exchange.properties.item}.");
                exchange.setProperty("name", "Christian");
                exchange.setProperty("item", "7");
            }
        });

        mock.assertIsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            public void configure() throws Exception {
                FreemarkerComponent fc = context.getComponent("freemarker", FreemarkerComponent.class);
                fc.setAllowTemplateFromHeader(true);

                from("direct:a")
                    .to("freemarker:dummy")
                    .to("mock:result");
            }
        };
    }
}
